{
    "$graph": [
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "sentieon",
                "driver"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": "$(inputs.threads)"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 110
                    },
                    "id": "#rw.cwl/advanced_options"
                },
                {
                    "type": "string",
                    "default": "ReadWriter",
                    "inputBinding": {
                        "position": 100,
                        "prefix": "--algo"
                    },
                    "id": "#rw.cwl/algo"
                },
                {
                    "type": [
                        {
                            "type": "array",
                            "items": [
                                "string",
                                "File"
                            ],
                            "inputBinding": {
                                "prefix": "-i"
                            }
                        }
                    ],
                    "inputBinding": {
                        "position": 10
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#rw.cwl/input_bam"
                },
                {
                    "type": [
                        "null",
                        "string",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--interval",
                        "position": 10
                    },
                    "id": "#rw.cwl/interval"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 150
                    },
                    "id": "#rw.cwl/output_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                "File"
                            ],
                            "inputBinding": {
                                "prefix": "-q",
                                "position": 10
                            }
                        }
                    ],
                    "id": "#rw.cwl/qcal"
                },
                {
                    "type": [
                        "null",
                        "string",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "-r"
                    },
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "id": "#rw.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--shard",
                        "position": 10
                    },
                    "id": "#rw.cwl/shard"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-t",
                        "position": 10
                    },
                    "id": "#rw.cwl/threads"
                }
            ],
            "stderr": "rw.log",
            "id": "#rw.cwl",
            "outputs": [
                {
                    "type": "File",
                    "id": "#rw.cwl/log",
                    "outputBinding": {
                        "glob": "rw.log"
                    }
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_file)"
                    },
                    "secondaryFiles": ".bai",
                    "id": "#rw.cwl/output"
                }
            ]
        },
        {
            "class": "Workflow",
            "doc": "run multiple rw stages sequentially using earlier step output as later stage input_bam",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": "$(inputs.threads)"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "record",
                            "fields": [
                                {
                                    "name": "#main/advanced_options/rw1",
                                    "type": [
                                        "null",
                                        {
                                            "type": "array",
                                            "items": "string"
                                        }
                                    ]
                                },
                                {
                                    "name": "#main/advanced_options/rw2",
                                    "type": [
                                        "null",
                                        {
                                            "type": "array",
                                            "items": "string"
                                        }
                                    ]
                                }
                            ]
                        }
                    ],
                    "id": "#main/advanced_options"
                },
                {
                    "type": [
                        "null",
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "id": "#main/reference"
                },
                {
                    "type": [
                        {
                            "type": "array",
                            "items": [
                                "string",
                                "File"
                            ]
                        }
                    ],
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#main/rw1_input_bam"
                },
                {
                    "type": "string",
                    "id": "#main/rw1_output"
                },
                {
                    "type": "string",
                    "id": "#main/rw2_output"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-t",
                        "position": 10
                    },
                    "id": "#main/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/rw2/output",
                    "id": "#main/output"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#main/advanced_options",
                            "valueFrom": "${ if (self.rw1) return self.rw1; else return null; }",
                            "id": "#main/rw1/advanced_options"
                        },
                        {
                            "source": "#main/rw1_input_bam",
                            "id": "#main/rw1/input_bam"
                        },
                        {
                            "source": "#main/rw1_output",
                            "id": "#main/rw1/output_file"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/rw1/reference"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/rw1/threads"
                        }
                    ],
                    "out": [
                        "#main/rw1/output"
                    ],
                    "run": "#rw.cwl",
                    "id": "#main/rw1"
                },
                {
                    "in": [
                        {
                            "source": "#main/advanced_options",
                            "valueFrom": "${ if (self.rw2) return self.rw2; else return null; }",
                            "id": "#main/rw2/advanced_options"
                        },
                        {
                            "source": "#main/rw1/output",
                            "valueFrom": "${ return [ self ]; }",
                            "id": "#main/rw2/input_bam"
                        },
                        {
                            "source": "#main/rw2_output",
                            "id": "#main/rw2/output_file"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/rw2/reference"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/rw2/threads"
                        }
                    ],
                    "out": [
                        "#main/rw2/output"
                    ],
                    "run": "#rw.cwl",
                    "id": "#main/rw2"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
